==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/gradientevbextfilter.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS gradientevbextfilter//
create function gradientevbextfilter(wid integer, von datetime(6), bis datetime(6),
  zvon time, zbis time, wtf varchar(20),
  vg1 varchar(3), wf1 varchar(250),
  m2 varchar(3), vg2 varchar(3), wf2 varchar(250),
  m3 varchar(3), vg3 varchar(3), wf3 varchar(250),
  m4 varchar(3), vg4 varchar(3), wf4 varchar(250), neh varchar(100)) returns varchar(50)
deterministic
sql security invoker
begin
  declare s, u, sx, sxx, syx, sy double;
  declare va, ba, vo, bo time;
  if TIME(zvon) < TIME(zbis)
   then
    set va = TIME(zvon);
    set ba = TIME(zbis);
    set vo = '24:00:00';
    set bo = '-00:00:01';
  else
    set va = '24:00:00';
    set ba = '-00:00:01';
    set vo = TIME(zvon);
    set bo = TIME(zbis);
  end if;
  set u = UNIX_TIMESTAMP(von);
      select sum(pow(UNIX_TIMESTAMP(datum)-u,2)), sum(UNIX_TIMESTAMP(datum)-u),
             count(datum), sum(ehwconv(wert,neh)*(UNIX_TIMESTAMP(datum)-u)),
             sum(ehwconv(wert,neh)) from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert,neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
        into sxx, sx, s, syx, sy;
  if sxx > 0
   then
    return 3600*(syx-sy*sx/s)/(sxx-sx*sx/s);
  else
     return '';
  end if;
end//

GRANT EXECUTE on FUNCTION gradientevbextfilter
  to logginglesen@'localhost', loggingtest@'localhost', 'loggingadmin'@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/gradientevbextfilter.sql <==
-- gradientevbextfilter.sql
--
-- function gradientevbextfilter(wid, von, bis, zvon, zbis, wtf, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4, neh) returns varchar
-- wid: werteindizesID
-- von: datetime from
-- bis: datetime to
-- zvon: time from
-- zbis: time to
-- wtf: set of weekdays
-- vg1: comparevalue 1
-- wf1: comparefunction 1
-- m2: OR|AND
-- vg2: comparevalue 2
-- wf2: comparefunction 2
-- m3: OR|AND
-- vg3: comparevalue 3
-- wf3: comparefunction 3
-- m4: OR|AND
-- vg4: comparevalue 4
-- wf4: comparefunction 4
-- neh: return in unit neh
-- return: gradient of values with extended filter for unit '[E]'

set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS gradientevbextfilter//
create function gradientevbextfilter(wid integer, von datetime(6), bis datetime(6),
  zvon time, zbis time, wtf varchar(20),
  vg1 varchar(3), wf1 varchar(250),
  m2 varchar(3), vg2 varchar(3), wf2 varchar(250),
  m3 varchar(3), vg3 varchar(3), wf3 varchar(250),
  m4 varchar(3), vg4 varchar(3), wf4 varchar(250), neh varchar(100)) returns varchar(50)
deterministic
sql security invoker
begin
  declare s, u, sx, sxx, syx, sy double;
  declare va, ba, vo, bo time;
  if TIME(zvon) < TIME(zbis)
   then
    set va = TIME(zvon);
    set ba = TIME(zbis);
    set vo = '24:00:00';
    set bo = '-00:00:01';
  else
    set va = '24:00:00';
    set ba = '-00:00:01';
    set vo = TIME(zvon);
    set bo = TIME(zbis);
  end if;
  set u = UNIX_TIMESTAMP(von);
      select sum(pow(UNIX_TIMESTAMP(datum)-u,2)), sum(UNIX_TIMESTAMP(datum)-u),
             count(datum), sum(ehwconv(wert,neh)*(UNIX_TIMESTAMP(datum)-u)), sum(ehwconv(wert,neh))
        into sxx, sx, s, syx, sy
        from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert,neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh));
  if sxx > 0
   then
    return 3600*(syx-sy*sx/s)/(sxx-sx*sx/s);
  else
     return '';
  end if;
end//

GRANT EXECUTE on FUNCTION gradientevbextfilter
  to logginglesen@'localhost', loggingtest@'localhost', 'loggingadmin'@'localhost'//
